@@ -20,7 +20,7 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 # IN THE SOFTWARE.
 
-from connection import SESConnection
+from boto.ses.connection import SESConnection
 from boto.regioninfo import RegionInfo, get_regions
 
 
