@@ -40,7 +40,7 @@ from boto.s3.lifecycle import Rule
 from boto.s3.acl import Grant
 from boto.s3.tagging import Tags, TagSet
 from boto.s3.website import RedirectLocation
-from boto.compat import urllib
+from boto.compat import unquote_str
 
 
 class S3BucketTest (unittest.TestCase):
@@ -88,8 +88,9 @@ class S3BucketTest (unittest.TestCase):
             self.assertEqual(element.name, expected.pop(0))
         self.assertEqual(expected, [])
 
+
     def test_list_with_url_encoding(self):
-        expected = ["α", "β", "γ"]
+        expected = [u"α", u"β", u"γ"]
         for key_name in expected:
             key = self.bucket.new_key(key_name)
             key.set_contents_from_string(key_name)
@@ -101,7 +102,7 @@ class S3BucketTest (unittest.TestCase):
         with patch.object(self.bucket, '_get_all', getall):
             rs = self.bucket.list(encoding_type="url")
             for element in rs:
-                name = urllib.parse.unquote(element.name.encode('utf-8'))
+                name = unquote_str(element.name)
                 self.assertEqual(name, expected.pop(0))
             self.assertEqual(expected, [])
 
