@@ -551,8 +551,16 @@ class TestS3SigV4OptIn(MockServiceWithConfigTestCase):
         self.assertEqual(fake._required_auth_capability(), ['nope'])
 
     def test_sigv4_non_optional(self):
-        region_groups = ['.cn-north', '.eu-central', '-eu-central']
-        specific_regions = ['.ap-northeast-2', '-ap-northeast-2']
+        region_groups = [
+            '.cn-north',
+            '.eu-central', '-eu-central',
+            '.ca-central', '-ca-central'
+        ]
+        specific_regions = [
+            '.ap-northeast-2', '-ap-northeast-2',
+            '.ap-south-1', '-ap-south-1',
+            '.us-east-2', '-us-east-2',
+        ]
 
         # Create a connection for a sample region in each of these groups
         # and ensure sigv4 is used.
@@ -568,7 +576,6 @@ class TestS3SigV4OptIn(MockServiceWithConfigTestCase):
             self.assertEqual(
                 fake._required_auth_capability(), ['hmac-v4-s3'])
 
-
     def test_sigv4_opt_in_config(self):
         # Opt-in via the config.
         self.config = {
