@@ -145,6 +145,24 @@ class TestAWSAuthConnection(unittest.TestCase):
         )
         self.assertEqual(conn.get_proxy_url_with_auth(), 'http://john.doe:p4ssw0rd@127.0.0.1:8180')
 
+    def test_build_base_http_request_noproxy(self):
+        os.environ['no_proxy'] = 'mockservice.cc-zone-1.amazonaws.com'
+
+        conn = AWSAuthConnection(
+            'mockservice.cc-zone-1.amazonaws.com',
+            aws_access_key_id='access_key',
+            aws_secret_access_key='secret',
+            suppress_consec_slashes=False,
+            proxy="127.0.0.1",
+            proxy_user="john.doe",
+            proxy_pass="p4ssw0rd",
+            proxy_port="8180"
+        )
+        request = conn.build_base_http_request('GET', '/', None)
+
+        del os.environ['no_proxy']
+        self.assertEqual(request.path, '/')
+
     def test_connection_behind_proxy_without_explicit_port(self):
         os.environ['http_proxy'] = "http://127.0.0.1"
         conn = AWSAuthConnection(
@@ -387,6 +405,26 @@ class TestAWSQueryConnectionSimple(TestAWSQueryConnection):
                                  'POST')
         self.assertEqual(resp.read(), b"{'test': 'success'}")
 
+    def test_unhandled_exception(self):
+        HTTPretty.register_uri(HTTPretty.POST,
+                               'https://%s/temp_exception/' % self.region.endpoint,
+                               responses=[])
+
+        def fake_connection(address, timeout=socket._GLOBAL_DEFAULT_TIMEOUT,
+                      source_address=None):
+            raise socket.timeout('fake error')
+
+        socket.create_connection = fake_connection
+
+        conn = self.region.connect(aws_access_key_id='access_key',
+                                   aws_secret_access_key='secret')
+        conn.num_retries = 0
+        with self.assertRaises(socket.error):
+            resp = conn.make_request('myCmd1',
+                                     {'par1': 'foo', 'par2': 'baz'},
+                                     '/temp_exception/',
+                                     'POST')
+
     def test_connection_close(self):
         """Check connection re-use after close header is received"""
         HTTPretty.register_uri(HTTPretty.POST,
@@ -484,7 +522,7 @@ class TestAWSQueryStatus(TestAWSQueryConnection):
 
 class TestHTTPRequest(unittest.TestCase):
     def test_user_agent_not_url_encoded(self):
-        headers = {'Some-Header': u'should be url encoded',
+        headers = {'Some-Header': u'should be encoded \u2713',
                    'User-Agent': UserAgent}
         request = HTTPRequest('PUT', 'https', 'amazon.com', 443, None,
                               None, {}, headers, 'Body')
@@ -501,9 +539,19 @@ class TestHTTPRequest(unittest.TestCase):
         # Ensure the headers at authorization are as expected i.e.
         # the user agent header was not url encoded but the other header was.
         self.assertEqual(mock_connection.headers_at_auth,
-                         {'Some-Header': 'should%20be%20url%20encoded',
+                         {'Some-Header': 'should be encoded %E2%9C%93',
                           'User-Agent': UserAgent})
 
+    def test_content_length_str(self):
+        request = HTTPRequest('PUT', 'https', 'amazon.com', 443, None,
+                              None, {}, {}, 'Body')
+        mock_connection = mock.Mock()
+        request.authorize(mock_connection)
+
+        # Ensure Content-Length header is a str. This is more explicit than
+        # relying on other code cast the value later. (Python 2.7.0, for
+        # example, assumes headers are of type str.)
+        self.assertIsInstance(request.headers['Content-Length'], str)
 
 if __name__ == '__main__':
     unittest.main()
